/*
 * StudioClientCommonConstants.java
 *
 * Copyright (C) 2022 by Posit Software, PBC
 *
 * Unless you have received this program directly from Posit Software pursuant
 * to the terms of a commercial license agreement with Posit Software, then
 * this program is licensed to you under the terms of version 3 of the
 * GNU Affero General Public License. This program is distributed WITHOUT
 * ANY EXPRESS OR IMPLIED WARRANTY, INCLUDING THOSE OF NON-INFRINGEMENT,
 * MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. Please refer to the
 * AGPL (http://www.gnu.org/licenses/agpl-3.0.txt) for more details.
 *
 */
package org.rstudio.studio.client.common;
public interface StudioClientCommonConstants extends com.google.gwt.i18n.client.Messages {
    String errorCaption();
    String stopTitle();
    String outputLeftLabel();
    String issuesRightLabel();
    String clearAllBreakpointsCaption();
    String hideTracebackText();
    String showTracebackText();
    String convertingThemeProgressCaption();
    String withDataImportMongoProgressCaption();
    String testthatMessage();
    String shinytest2Message();
    String preparingTestsProgressCaption();
    String testingToolsContext();
    String noFilesSelectedCaption();
    String noFilesSelectedMessage();
    String downloadButtonCaption();
    String rCodeBrowserLabel();
    String rDataFrameLabel();
    String publicFolderDesc();
    String folderDesc();
    String textFileDesc();
    String imageFileDesc();
    String parentFolderDesc();
    String exploreObjectDesc();
    String rSourceViewerDesc();
    String profilerDesc();
    String rScriptLabel();
    String rdFile();
    String namespaceLabel();
    String rHistoryLabel();
    String rMarkdownLabel();
    String rNotebookLabel();
    String markdownLabel();
    String fileDownloadErrorCaption();
    String fileDownloadErrorMessage();
    String openLabel();
    String saveLabel();
    String chooseLabel();
    String andText();
    String typesetLatexLabel();
    String latexHelpLinkLabel();
    String errorSettingCranMirror();
    String cranMirrorCannotChange();
    String insertRoxygenSkeletonMessage();
    String unableToInsertSkeletonMessage();
    String cannotUpdateRoxygenMessage();
    String confirmChangeCaption();
    String packageRequiredMessage(String packageName, String name);
    String uploadErrorTitle();
    String unableToContinueMessage();
    String uploadingDocumentRPubsMessage();
    String publishToRPubs();
    String rPubsServiceMessage();
    String alreadyPublishedRPubs();
    String importantMessage();
    String publishMessage();
    String importantRPubsMessage(String importantMessage, String publishMessage);
    String publishButtonTitle();
    String updateExistingButtonTitle();
    String createNewButtonTitle();
    String cancelTitle();
    String okTitle();
    String usingKeyringCaption();
    String keyringDesc();
    String installKeyringMessage();
    String keyringCaption();
    String installLabel();
    String enterValueMessage();
    String consoleOutputOverLimitMessage();
    String consoleWriteError(String error);
    String lineText();
    String viewErrorLogfile();
    String getSyncProgressMessage();
    String pdfPageText();
    String pdfFromClickText();
    String passwordTitle();
    String patTitle();
    String patPrompt();
    String usernameTitle();
    String pressLabel(String cmdText);
    String closeButtonLabel();
    String noneLabel();
    String gettingIgnoredFilesProgressMessage();
    String settingIgnoredFilesProgressMessage();
    String multipleDirectoriesCaption();
    String selectedFilesNotInSameDirectoryMessage();
    String directoryLabel();
    String ignoredFilesLabel();
    String ignoreCaption();
    String specifyingIgnoredFilesHelpCaption();
    String loadingFileContentsProgressCaption();
    String saveAsText();
    String saveFileCaption(String name);
    String savingFileProgressCaption();
    String viewFileTabLabel();
    String atText();
    String warningMessage();
    String rPresentationLabel();
    String sourceMarkerItemTableList();
    String previewButtonText();
    String genericContentLabel();
    String objectExplorerLabel();
    String rProfilerLabel();
    String checkPreviewButtonText();
    String weaveRnwLabel();
    String weaveRnwHelpTitle();
    String sshRSAKeyFormLabel();
    String viewPublicKeyCaption();
    String createRSAKeyButtonLabel();
    String readingPublicKeyProgressCaption();
    String clearAllBreakpointsMessage();
    String functionNameText(String functionName, String source);
    String showFileExportLabel(String description);
    String accountListLabel();
    String connectButtonLabel();
    String reconnectButtonLabel();
    String disconnectButtonLabel();
    String missingPkgPanelMessage();
    String missingPkgRequiredMessage();
    String installPkgsMessage();
    String withRSConnectLabel();
    String chkEnableRSConnectLabel();
    String checkBoxWithHelpTitle();
    String settingsHeaderLabel();
    String chkEnablePublishingLabel();
    String showPublishDiagnosticsLabel();
    String sSLCertificatesHeaderLabel();
    String publishCheckCertificatesLabel();
    String usePublishCaBundleLabel();
    String caBundlePath();
    String helpLinkTroubleshooting();
    String publishingPaneHeader();
    String showErrorCaption();
    String removeAccountGlobalDisplay();
    String onConfirmDisconnectYesLabel();
    String onConfirmDisconnectNoLabel();
    String disconnectingErrorMessage();
    String getAccountCountLabel();
    String connectAccountCaption();
    String connectAccountOkCaption();
    String newRSConnectAccountPageTitle();
    String newRSConnectAccountPageSubTitle();
    String newRSConnectAccountPageCaption();
    String wizardNavigationPageTitle();
    String wizardNavigationPageSubTitle();
    String wizardNavigationPageCaption();
    String serviceDescription();
    String serviceMessageDescription();
    String newRSConnectCloudPageSubTitle();
    String newRSConnectCloudPageSub();
    String newRSConnectCloudPageCaption();
    String withThemesCaption();
    String withRMarkdownCaption();
    String installShinyCaption();
    String installShinyUserAction(String userAction);
    String installPkgsCaption();
    String withShinyAddinsCaption();
    String withShinyAddinsUserAction();
    String withStylerCaption();
    String withStylerUserAction();
    String withDataImportCSVCaption();
    String withDataImportSAV();
    String withDataImportXLS();
    String withDataImportXML();
    String withDataImportJSON();
    String withDataImportJDBC();
    String withDataImportODBC();
    String withProfvis();
    String withConnectionPackage();
    String withConnectionPackageContext();
    String withKeyring();
    String withKeyringUserAction();
    String withOdbc();
    String withOdbcUserAction();
    String withTutorialDependencies();
    String withTutorialDependenciesUserAction();
    String withRagg();
    String withDatabricksConnect();
    String unsatisfiedVersions();
    String requiredVersion(String version);
    String packageNotFoundUserAction();
    String packageNotFoundMessage(String unsatisfiedVersions);
    String onErrorMessage();
    String availablePackageErrorMessage();
    String confirmPackageInstallation(String name);
    String updatedVersionMessage(String dependency);
    String installRequiredCaption();
    String globalDisplayEnable();
    String globalDisplayDisable();
    String globalDisplayVC();
    String globalDisplayVCMessage();
    String terminalPathLabel();
    String showPublicKeyDialogCaption();
    String onSSHErrorMessage(String keyPath, String errorMessage);
    String vCSHelpLink();
    String createKeyDialogCaption();
    String onProgressLabel();
    String setOkButtonCaption();
    String showValidateErrorCaption();
    String showValidateErrorMessage();
    String pathCaption();
    String pathHelpCaption();
    String sshKeyTypeLabel();
    String sshKeyRSAOption();
    String sshKeyEd25519Option();
    String passphraseLabel();
    String passphraseConfirmLabel();
    String confirmOverwriteKeyCaption();
    String confirmOverwriteKeyMessage(String path);
    String spellingLanguageSelectWidgetLabel();
    String addHelpButtonLabel();
    String progressDownloadingLabel();
    String progressDownloadingLanguagesLabel();
    String onErrorDownloadingCaption();
    String includeDefaultOption();
    String allLanguagesInstalledOption();
    String installIndexOption();
    String buttonAddLabel();
    String buttonRemoveLabel();
    String labelWithHelpText();
    String labelWithHelpTitle();
    String fileDialogsCaption();
    String fileDialogsFilter();
    String onProgressAddingLabel();
    String removeDictionaryCaption();
    String removeDictionaryMessage(String dictionary);
    String progressRemoveIndicator();
    String consoleBufferedMessage(int bufferSize);
}
